# -*- coding: utf-8 -*-
from setuphelpers import *


def install():
    print("Disabling: Hibernation")
    run_notfatal("powercfg.exe /hibernate off")
    registry_set(HKEY_LOCAL_MACHINE, r"SYSTEM\CurrentControlSet\Control\Power", "HibernateEnabled", 0)
    registry_set(HKEY_LOCAL_MACHINE, r"SYSTEM\CurrentControlSet\Control\Power", "HibernateEnabledDefault", 0)

    # Forget duplicate packages
    for p in WAPT.installed():
        if "disabled-hibernation" in p.package:
            WAPT.forget_packages(p.package)


def uninstall():
    print("Re-Enabling: Hibernation")
    run_notfatal("powercfg.exe /hibernate on")
    registry_set(HKEY_LOCAL_MACHINE, r"SYSTEM\CurrentControlSet\Control\Power", "HibernateEnabled", 1)
    registry_set(HKEY_LOCAL_MACHINE, r"SYSTEM\CurrentControlSet\Control\Power", "HibernateEnabledDefault", 1)


def audit():
    # Declaring local variables
    audit_status = "OK"
    hibernation_state = registry_readstring(HKEY_LOCAL_MACHINE, r"SYSTEM\CurrentControlSet\Control\Power", "HibernateEnabled")
    hiberfile_sys_file = makepath(systemdrive, "hiberfil.sys")

    # Auditing package
    if hibernation_state == "1":
        print("Hibernation is enabled.")
        audit_status = set_audit_status(audit_status, "ERROR")
    elif hibernation_state == "0":
        print("Hibernation is disabled.")
        # audit_status = set_audit_status(audit_status, "OK")
    if isfile(hiberfile_sys_file):
        print(f'"{hiberfile_sys_file}" exists. Please make sure that hibernation is disabled, the computer may need to be restarted.')
        audit_status = set_audit_status(audit_status, "WARNING")

    return audit_status


def set_audit_status(old_audit_status, new_audit_status):
    """Maintain higher criticality for audit status."""
    audit_level = {"OK": 0, "WARNING": 1, "ERROR": 2}

    old_status = old_audit_status.upper().strip()
    new_status = new_audit_status.upper().strip()

    if audit_level.get(new_status, -1) > audit_level.get(old_status, -1):
        return new_status
    else:
        return old_audit_status
